package devices

import (
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
	"server/dao/devices"
	"server/global"
	"server/model/common/request"
	"server/model/common/response"
	model "server/model/devices"
	"server/utils"
)

type CameraApi struct{}

func (cameraApi *CameraApi) CameraList(c *gin.Context) {
	var pageInfo request.PageInfo
	err := c.ShouldBindJSON(&pageInfo)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	err = utils.Verify(pageInfo, utils.PageInfoVerify)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	list, total, err := CameraService.GetCameraInfoList(pageInfo)
	if err != nil {
		global.GVA_LOG.Error("获取失败!", zap.Error(err))
		response.FailWithMessage("获取失败", c)
		return
	}
	response.OkWithDetailed(response.PageResult{
		List:     list,
		Total:    total,
		Page:     pageInfo.Page,
		PageSize: pageInfo.PageSize,
	}, "获取成功", c)
}

func (cameraApi *CameraApi) DelCamera(c *gin.Context) {
	var reqId request.GetById
	err := c.ShouldBindJSON(&reqId)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	err = utils.Verify(reqId, utils.IdVerify)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}

	err = CameraService.DelCamera(reqId.ID)
	if err != nil {
		global.GVA_LOG.Error("删除失败!", zap.Error(err))
		response.FailWithMessage("删除失败", c)
		return
	}
	response.OkWithMessage("删除成功", c)
}

func (cameraApi *CameraApi) AddCamera(c *gin.Context) {
	var ca model.ReqCamera
	err := c.ShouldBindJSON(&ca)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	camera := devices.Camera{
		CameraName:    ca.CameraName,
		CameraCode:    ca.CameraCode,
		CameraType:    ca.CameraType,
		GatewayId:     ca.GatewayID,
		CameraBrand:   ca.CameraBrand,
		CameraModel:   ca.CameraModel,
		IPAddress:     ca.IpAddress,
		InstallTime:   ca.InstallTime,
		Shunt:         ca.Shunt,
		ShuntDescribe: ca.ShuntDescribe,
		StreamId:      ca.StreamId,
	}
	err = CameraService.AddCamera(camera)
	if err != nil {
		global.GVA_LOG.Error(err.Error(), zap.Error(err))
		response.FailWithMessage(err.Error(), c)
		return
	}
	response.OkWithMessage("添加成功", c)
}

func (cameraApi *CameraApi) UpdateCamera(c *gin.Context) {
	var ca model.ReqCamera
	err := c.ShouldBindJSON(&ca)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	err = utils.Verify(ca, utils.IdVerify)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}

	camera := devices.Camera{
		ID:            ca.ID,
		CameraName:    ca.CameraName,
		CameraCode:    ca.CameraCode,
		CameraType:    ca.CameraType,
		GatewayId:     ca.GatewayID,
		CameraBrand:   ca.CameraBrand,
		CameraModel:   ca.CameraModel,
		IPAddress:     ca.IpAddress,
		InstallTime:   ca.InstallTime,
		Shunt:         ca.Shunt,
		ShuntDescribe: ca.ShuntDescribe,
		StreamId:      ca.StreamId,
	}
	err = CameraService.UpdateCamera(camera)
	if err != nil {
		global.GVA_LOG.Error("设置失败!", zap.Error(err))
		response.FailWithMessage("设置失败", c)
		return
	}
	response.OkWithMessage("设置成功", c)
}
