package devices

import (
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
	"server/dao/devices"
	"server/global"
	"server/model/common/request"
	"server/model/common/response"
	model "server/model/devices"
	"server/utils"
)

type ScreensApi struct{}

func (s *ScreensApi) QueryScreensParms(c *gin.Context) {
	list, err := ScreensService.QueryScreensParms()
	if err != nil {
		global.GVA_LOG.Error("获取屏参失败!", zap.Error(err))
		response.FailWithMessage("获取失败", c)
		return
	}
	response.OkWithDetailed(list, "获取成功", c)
}

func (s *ScreensApi) ScreensList(c *gin.Context) {
	var pageInfo request.PageInfo
	err := c.ShouldBindJSON(&pageInfo)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	err = utils.Verify(pageInfo, utils.PageInfoVerify)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	list, total, err := ScreensService.GetScreensInfoList(pageInfo)
	if err != nil {
		global.GVA_LOG.Error("获取失败!", zap.Error(err))
		response.FailWithMessage("获取失败", c)
		return
	}
	response.OkWithDetailed(response.PageResult{
		List:     list,
		Total:    total,
		Page:     pageInfo.Page,
		PageSize: pageInfo.PageSize,
	}, "获取成功", c)
}

func (s *ScreensApi) DelScreens(c *gin.Context) {
	var reqId request.GetById
	err := c.ShouldBindJSON(&reqId)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	err = utils.Verify(reqId, utils.IdVerify)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}

	err = ScreensService.DelScreens(reqId.ID)
	if err != nil {
		global.GVA_LOG.Error("删除失败!", zap.Error(err))
		response.FailWithMessage("删除失败", c)
		return
	}
	response.OkWithMessage("删除成功", c)
}

func (s *ScreensApi) AddScreens(c *gin.Context) {
	var sc model.ReqScreens
	err := c.ShouldBindJSON(&sc)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	screens := devices.Screens{
		ScreensName:   sc.ScreensName,
		ScreensCode:   sc.ScreensCode,
		ScreensBrand:  sc.ScreensBrand,
		ScreensModel:  sc.ScreensModel,
		IPAddress:     sc.IpAddress,
		GatewayId:     sc.GatewayID,
		ResolutionId:  sc.ResolutionId,
		ScreensSizeId: sc.ScreensSizeId,
		Shunt:         sc.Shunt,
		ShuntDescribe: sc.ShuntDescribe,
		InstallTime:   sc.InstallTime,
	}
	err = ScreensService.AddScreens(screens)
	if err != nil {
		global.GVA_LOG.Error(err.Error(), zap.Error(err))
		response.FailWithMessage(err.Error(), c)
		return
	}
	response.OkWithMessage("添加成功", c)
}

func (s *ScreensApi) UpdateScreens(c *gin.Context) {
	var sc model.ReqScreens
	err := c.ShouldBindJSON(&sc)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	err = utils.Verify(sc, utils.IdVerify)
	if err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}

	screens := devices.Screens{
		ID:            sc.ID,
		ScreensName:   sc.ScreensName,
		ScreensCode:   sc.ScreensCode,
		ScreensBrand:  sc.ScreensBrand,
		ScreensModel:  sc.ScreensModel,
		IPAddress:     sc.IpAddress,
		GatewayId:     sc.GatewayID,
		ResolutionId:  sc.ResolutionId,
		ScreensSizeId: sc.ScreensSizeId,
		Shunt:         sc.Shunt,
		ShuntDescribe: sc.ShuntDescribe,
		InstallTime:   sc.InstallTime,
	}
	err = ScreensService.UpdateScreens(screens)
	if err != nil {
		global.GVA_LOG.Error("设置失败!", zap.Error(err))
		response.FailWithMessage("设置失败", c)
		return
	}
	response.OkWithMessage("设置成功", c)
}
